@@ -22,13 +22,14 @@ distHaversine <- function(p1, p2, r=6378137) {
 	p1 <- .pointsToMatrix(p1) * toRad
 	p2 <- .pointsToMatrix(p2) * toRad
 
-	.compareDim(p1, p2)
-
-	lon1 <- p1[,1]
-	lat1 <- p1[,2]
-	lon2 <- p2[,1]
-	lat2 <- p2[,2]
-  
+	p = cbind(p1[,1], p1[,2], p2[,1], p2[,2], as.vector(r))
+	
+	lon1 <- p[,1]
+	lat1 <- p[,2]
+	lon2 <- p[,3]
+	lat2 <- p[,4]
+	r <- p[,5]
+	
 	dLat <- (lat2-lat1)
 	dLon <- (lon2-lon1)
 	a <- sin(dLat/2) * sin(dLat/2) + cos(lat1) * cos(lat2) * sin(dLon/2) * sin(dLon/2)
